@@ -1,6 +1,7 @@
 from .resource import Resource
 from .document import Document
-from .view import View
+from .design import Design
+from .index import Index
 
 
 class Database(Resource):
@@ -18,6 +19,16 @@ class Database(Resource):
         opts = dict(self.opts.items() + kwargs.items())
         return Document(self._make_url(name), session=self._session, **opts)
 
+    def design(self, name, **kwargs):
+        """
+        Create a `Design` object from `name`, like so:
+
+            db.design('test')
+            # refers to DB/_design/test
+        """
+        opts = dict(self.opts.items() + kwargs.items())
+        return Design(self._make_url('/'.join(['_design', name])), session=self._session, **opts)
+
     def __getitem__(self, name):
         """Shortcut to `Database.document`."""
         return self.document(name, **self.opts)
@@ -28,13 +39,13 @@ class Database(Resource):
 
     def all_docs(self, **kwargs):
         """
-        Return a `View` object referencing all documents in the database.
+        Return an `Index` object referencing all documents in the database.
         You can treat it like an iterator:
 
             for doc in db.all_docs():
                 print doc
         """
-        return View(self._make_url('_all_docs'), session=self._session, **kwargs)
+        return Index(self._make_url('_all_docs'), session=self._session, **kwargs)
 
     def __iter__(self):
         """Formats `Database.all_docs` for use as an iterator."""
